/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of PeerfactSim.KOM.
 * 
 * PeerfactSim.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.uavsupport.communication;

import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.LinkedList;

import de.tudarmstadt.maki.simonstrator.api.component.overlay.OverlayContact;
import de.tudarmstadt.maki.simonstrator.api.component.overlay.OverlayMessage;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;

/**
 * Interface simulating direct hardware connection from Base to UAVs.
 * 
 * @author Julian Zobel
 *
 */
public interface BaseToUAVInterface<T extends OverlayMessage, S extends Location> {
	/**
	 * Connect the UAV to the base.
	 * 
	 * @param uav
	 */
	public void connectUAVtoBase(UAVToBaseInterface<T, S> uav);
	
	/**
	 * Disconnect UAV from base.
	 * 
	 * @param uav
	 */
	public void disconnectUAV(UAVToBaseInterface<T, S> uav);

	/**
	 * Mark an already connected UAV to be ready for assignments.
	 * 
	 * @param uav
	 */
	public void readyUAV(UAVToBaseInterface<T, S> uav);

	/**
	 * Update the message buffer with a given list of buffered messages.
	 * Messages will only be added if not expired and not already in the buffer.
	 * 
	 * @param communicationMessages
	 *            List of data messages
	 */
	public void addCommunicationData(LinkedHashSet<T> communicationMessages);

	/**
	 * Update the monitoring information with a map of monitored locations
	 * sorted by each encountered node.
	 * 
	 * @param monitoringData
	 */
	public void addMonitoringData(LinkedHashMap<OverlayContact, LinkedList<S>> monitoringData,
			boolean acquiredByMonitoringUAV);

}
